@@ -1,40 +1,37 @@
 /*
- * Copyright (c) 2000-2003 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ * Copyright (c) 2000-2004 Silicon Graphics, Inc.  All Rights Reserved.
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
  * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
-#define ustat __kernel_ustat
 #include <xfs/libxfs.h>
 #include <sys/stat.h>
-#undef ustat
-#include <sys/ustat.h>
 #include <sys/wait.h>
 #include <pthread.h>
 #include <signal.h>
@@ -43,6 +40,8 @@
 
 #define	rounddown(x, y)	(((x)/(y))*(y))
 
+extern int	platform_check_ismounted(char *, char *, struct stat64 *, int);
+
 int		logfd;
 char 		*logfile_name;
 FILE		*logerr;
@@ -222,6 +221,7 @@ handle_error:
 		pthread_mutex_unlock(&mainwait);
 	pthread_mutex_unlock(&glob_masks.mutex);
 	pthread_exit(NULL);
+	return NULL;
 }
 
 void
@@ -280,7 +280,7 @@ handler()
 					pthread_exit(NULL);
 				}
 
-				sigset(SIGCLD, handler);
+				signal(SIGCHLD, handler);
 				return;
 			} else  {
 				/* it just croaked it bigtime, log it */
@@ -302,7 +302,7 @@ handler()
 	do_warn(_("%s: Unknown child died (should never happen!)\n"), progname);
 	die_perror();
 	pthread_exit(NULL);
-	sigset(SIGCLD, handler);
+	signal(SIGCHLD, handler);
 }
 
 void
@@ -482,9 +482,9 @@ write_wbuf(void)
 		if (target[i].state != INACTIVE)
 			pthread_mutex_unlock(&targ[i].wait);	/* wake up */
 
-	sigrelse(SIGCLD);
+	sigrelse(SIGCHLD);
 	pthread_mutex_lock(&mainwait);
-	sighold(SIGCLD);
+	sighold(SIGCHLD);
 }
 
 
@@ -496,7 +496,8 @@ main(int argc, char **argv)
 	int		open_flags;
 	xfs_off_t	pos, end_pos;
 	size_t		length;
-	int		c, size, sizeb, first_residue, tmp_residue;
+	int		c, first_residue, tmp_residue;
+	__uint64_t	size, sizeb;
 	__uint64_t	numblocks = 0;
 	int		wblocks = 0;
 	int		num_threads = 0;
@@ -506,7 +507,7 @@ main(int argc, char **argv)
 	int		wbuf_miniosize;
 	int		source_is_file = 0;
 	int		buffered_output = 0;
-	int		duplicate_uuids = 0;
+	int		duplicate = 0;
 	uint		btree_levels, current_level;
 	ag_header_t	ag_hdr;
 	xfs_mount_t	*mp;
@@ -523,7 +524,6 @@ main(int argc, char **argv)
 	extern int	optind;
 	libxfs_init_t	xargs;
 	thread_args	*tcarg;
-	struct ustat	ustat_buf;
 	struct stat64	statbuf;
 
 	progname = basename(argv[0]);
@@ -538,7 +538,7 @@ main(int argc, char **argv)
 			buffered_output = 1;
 			break;
 		case 'd':
-			duplicate_uuids = 1;
+			duplicate = 1;
 			break;
 		case 'L':
 			logfile_name = optarg;
@@ -647,7 +647,7 @@ main(int argc, char **argv)
 		 * check to make sure a filesystem isn't mounted
 		 * on the device
 		 */
-		if (ustat(statbuf.st_rdev, &ustat_buf) == 0)  {
+		if (platform_check_ismounted(source_name, NULL, &statbuf, 0))  {
 			do_log(
 	_("%s:  Warning -- a filesystem is mounted on the source device.\n"),
 				progname);
@@ -682,7 +682,7 @@ main(int argc, char **argv)
 	sbp = libxfs_readbuf(xargs.ddev, XFS_SB_DADDR, 1, 0);
 	memset(&mbuf, 0, sizeof(xfs_mount_t));
 	sb = &mbuf.m_sb;
-	libxfs_xlate_sb(XFS_BUF_PTR(sbp), sb, 1, ARCH_CONVERT, XFS_SB_ALL_BITS);
+	libxfs_xlate_sb(XFS_BUF_PTR(sbp), sb, 1, XFS_SB_ALL_BITS);
 
 	mp = libxfs_mount(&mbuf, sb, xargs.ddev, xargs.logdev, xargs.rtdev, 1);
 	if (mp == NULL) {
@@ -760,7 +760,8 @@ main(int argc, char **argv)
 			 * check to make sure a filesystem isn't mounted
 			 * on the device
 			 */
-			if (ustat(statbuf.st_rdev, &ustat_buf) == 0)  {
+			if (platform_check_ismounted(target[i].name,
+							NULL, &statbuf, 0))  {
 				do_log(_("%s:  a filesystem is mounted "
 					"on target device \"%s\".\n"
 					"%s cannot copy to mounted filesystems."
@@ -850,8 +851,8 @@ main(int argc, char **argv)
 
 	/* set up sigchild signal handler */
 
-	sigset(SIGCLD, handler);
-	sighold(SIGCLD);
+	signal(SIGCHLD, handler);
+	sighold(SIGCHLD);
 
 	/* make children */
 
@@ -862,7 +863,7 @@ main(int argc, char **argv)
 	}
 
 	for (i = 0, tcarg = targ; i < num_targets; i++, tcarg++)  {
-		if (!duplicate_uuids)
+		if (!duplicate)
 			uuid_generate(tcarg->uuid);
 		else
 			uuid_copy(tcarg->uuid, mp->m_sb.sb_uuid);
@@ -961,7 +962,7 @@ main(int argc, char **argv)
 			ptr = XFS_BTREE_PTR_ADDR(sourceb_blocksize, xfs_alloc,
 				block, 1, mp->m_alloc_mxr[1]),
 
-			bno = *ptr;
+			bno = INT_GET(ptr[0], ARCH_CONVERT);
 		}
 
 		/* align first data copy but don't overwrite ag header */
@@ -1119,30 +1120,33 @@ main(int argc, char **argv)
 	}
 
 	if (kids > 0)  {
-		/* write a clean log using the specified UUID */
+		if (!duplicate)  {
 
-		for (j = 0, tcarg = targ; j < num_targets; j++)  {
-			w_buf.owner = tcarg;
-			w_buf.length = rounddown(w_buf.size, w_buf.min_io_size);
+			/* write a clean log using the specified UUID */
+			for (j = 0, tcarg = targ; j < num_targets; j++)  {
+				w_buf.owner = tcarg;
+				w_buf.length = rounddown(w_buf.size,
+							 w_buf.min_io_size);
+				pos = write_log_header(
+							source_fd, &w_buf, mp);
+				end_pos = write_log_trailer(
+							source_fd, &w_buf, mp);
+				w_buf.position = pos;
+				memset(w_buf.data, 0, w_buf.length);
 
-			pos = write_log_header(source_fd, &w_buf, mp);
-			end_pos = write_log_trailer(source_fd, &w_buf, mp);
-
-			w_buf.position = pos;
-			memset(w_buf.data, 0, w_buf.length);
-
-			while (w_buf.position < end_pos)  {
-				do_write(tcarg);
-				w_buf.position += w_buf.length;
+				while (w_buf.position < end_pos)  {
+					do_write(tcarg);
+					w_buf.position += w_buf.length;
+				}
+				tcarg++;
 			}
-			tcarg++;
+		} else {
+			num_ags = 1;
 		}
 
 		/* reread and rewrite superblocks (UUID and in-progress) */
 		/* [backwards, so inprogress bit only updated when done] */
 
-		if (duplicate_uuids)
-			num_ags = 1;
 		for (i = num_ags - 1; i >= 0; i--)  {
 			read_ag_header(source_fd, i, &w_buf, &ag_hdr, mp,
 				source_blocksize, source_sectorsize);
