@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2004-2005 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -31,10 +31,10 @@
  */
 
 #include <xfs/libxfs.h>
+#include <xfs/command.h>
+#include <xfs/input.h>
 #include <sys/mman.h>
 #include <signal.h>
-#include "command.h"
-#include "input.h"
 #include "init.h"
 #include "io.h"
 
@@ -69,7 +69,7 @@ print_mapping(
 
 	for (i = 0, p = pflags; p->prot != PROT_NONE; i++, p++)
 		buffer[i] = (map->prot & p->prot) ? p->mode : '-';
-	printf("%c%d%c 0x%lx - 0x%lx %s  %14s (%lld : %ld)\n",
+	printf("%c%03d%c 0x%lx - 0x%lx %s  %14s (%lld : %ld)\n",
 		braces? '[' : ' ', index, braces? ']' : ' ',
 		(unsigned long)map->addr,
 		(unsigned long)((char *)map->addr + map->length),
@@ -171,7 +171,7 @@ mmap_f(
 	ssize_t		length;
 	void		*address;
 	char		*filename;
-	int		blocksize, sectsize;
+	unsigned int	blocksize, sectsize;
 	int		c, prot = 0;
 
 	if (argc == 1) {
@@ -286,7 +286,8 @@ msync_f(
 	off64_t		offset;
 	ssize_t		length;
 	void		*start;
-	int		c, flags = 0, blocksize, sectsize;
+	int		c, flags = 0;
+	unsigned int	blocksize, sectsize;
 
 	while ((c = getopt(argc, argv, "ais")) != EOF) {
 		switch (c) {
@@ -391,8 +392,8 @@ mread_f(
 	size_t		dumplen;
 	char		*bp;
 	void		*start;
-	int		dump = 0, rflag = 0;
-	int		c, blocksize, sectsize;
+	int		dump = 0, rflag = 0, c;
+	unsigned int	blocksize, sectsize;
 
 	while ((c = getopt(argc, argv, "frv")) != EOF) {
 		switch (c) {
@@ -537,7 +538,8 @@ mwrite_f(
 	char		*sp;
 	int		seed = 'X';
 	int		rflag = 0;
-	int		c, blocksize, sectsize;
+	int		c;
+	unsigned int	blocksize, sectsize;
 
 	while ((c = getopt(argc, argv, "rS:")) != EOF) {
 		switch (c) {
