@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2004 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2003-2005 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -31,8 +31,8 @@
  */
 
 #include <xfs/libxfs.h>
-#include "command.h"
-#include "input.h"
+#include <xfs/command.h>
+#include <xfs/input.h>
 #include "init.h"
 #include "io.h"
 
@@ -41,9 +41,10 @@ static cmdinfo_t stat_cmd;
 static cmdinfo_t close_cmd;
 static cmdinfo_t setfl_cmd;
 static cmdinfo_t statfs_cmd;
-static cmdinfo_t chattr_cmd;
-static cmdinfo_t lsattr_cmd;
+static cmdinfo_t chproj_cmd;
+static cmdinfo_t lsproj_cmd;
 static cmdinfo_t extsize_cmd;
+static prid_t prid;
 
 off64_t
 filesize(void)
@@ -79,50 +80,6 @@ filetype(mode_t mode)
 	return NULL;
 }
 
-static void
-printxattr(int flags, int verbose, int dofname, int dobraces, int doeol)
-{
-	static struct {
-		int	flag;
-		char	*shortname;
-		char	*longname;
-	} *p, xflags[] = {
-		{ XFS_XFLAG_REALTIME,	"r", "realtime" },
-		{ XFS_XFLAG_PREALLOC,	"p", "prealloc" },
-		{ XFS_XFLAG_IMMUTABLE,	"i", "immutable" },
-		{ XFS_XFLAG_APPEND,	"a", "append-only" },
-		{ XFS_XFLAG_SYNC,	"s", "sync" },
-		{ XFS_XFLAG_NOATIME,	"A", "no-atime" },
-		{ XFS_XFLAG_NODUMP,	"d", "no-dump" },
-		{ 0, NULL, NULL }
-	};
-	int	first = 1;
-
-	if (dobraces)
-		fputs("[", stdout);
-	for (p = xflags; p->flag; p++) {
-		if (flags & p->flag) {
-			if (verbose) {
-				if (first)
-					first = 0;
-				else
-					fputs(", ", stdout);
-				fputs(p->longname, stdout);
-			} else {
-				fputs(p->shortname, stdout);
-			}
-		} else if (!verbose) {
-			fputs("-", stdout);
-		}
-	}
-	if (dobraces)
-		fputs("]", stdout);
-	if (dofname)
-		printf(" %s ", file->name);
-	if (doeol)
-		fputs("\n", stdout);
-}
-
 static int
 stat_f(
 	int		argc,
@@ -133,12 +90,13 @@ stat_f(
 	int		verbose = (argc == 2 && !strcmp(argv[1], "-v"));
 
 	printf(_("fd.path = \"%s\"\n"), file->name);
-	printf(_("fd.flags = %s,%s,%s%s%s\n"),
+	printf(_("fd.flags = %s,%s,%s%s%s%s\n"),
 		file->flags & IO_OSYNC ? _("sync") : _("non-sync"),
 		file->flags & IO_DIRECT ? _("direct") : _("non-direct"),
 		file->flags & IO_READONLY ? _("read-only") : _("read-write"),
 		file->flags & IO_REALTIME ? _(",real-time") : "",
-		file->flags & IO_APPEND ? _(",append-only") : "");
+		file->flags & IO_APPEND ? _(",append-only") : "",
+		file->flags & IO_NONBLOCK ? _(",non-block") : "");
 	if (fstat64(file->fd, &st) < 0) {
 		perror("fstat64");
 	} else {
@@ -158,7 +116,7 @@ stat_f(
 		perror("XFS_IOC_FSGETXATTR");
 	} else {
 		printf(_("xattr.xflags = 0x%x "), fsx.fsx_xflags);
-		printxattr(fsx.fsx_xflags, verbose, 0, 1, 1);
+		printxattr(fsx.fsx_xflags, verbose, 0, file->name, 1, 1);
 		printf(_("xattr.extsize = %u\n"), fsx.fsx_extsize);
 		printf(_("xattr.nextents = %u\n"), fsx.fsx_nextents);
 	}
@@ -186,6 +144,8 @@ openfile(
 		oflags |= O_SYNC;
 	if (flags & IO_TRUNC)
 		oflags |= O_TRUNC;
+	if (flags & IO_NONBLOCK)
+		oflags |= O_NONBLOCK;
 
 	fd = open(path, oflags, mode);
 	if (fd < 0) {
@@ -199,7 +159,7 @@ openfile(
 	if (!platform_test_xfs_fd(fd)) {
 		fprintf(stderr, _("%s: specified file "
 			"[\"%s\"] is not on an XFS filesystem\n"),
-			progname, file->name);
+			progname, path);
 		close(fd);
 		return -1;
 	}
@@ -283,10 +243,11 @@ open_help(void)
 " -d -- open with O_DIRECT (non-buffered IO, note alignment constraints)\n"
 " -f -- open with O_CREAT (create the file if it doesn't exist)\n"
 " -m -- permissions to use in case a new file is created (default 0600)\n"
+" -n -- open with O_NONBLOCK\n"
 " -r -- open with O_RDONLY, the default is O_RDWR\n"
 " -s -- open with O_SYNC\n"
 " -t -- open with O_TRUNC (truncate the file to zero length if it exists)\n"
-" -x -- mark the file as a realtime XFS file immediately after opening it\n"
+" -R -- mark the file as a realtime XFS file immediately after opening it\n"
 " Note1: usually read/write direct IO requests must be blocksize aligned;\n"
 "        some kernels, however, allow sectorsize alignment for direct IO.\n"
 " Note2: the bmap for non-regular files can be obtained provided the file\n"
@@ -311,7 +272,7 @@ open_f(
 		return 0;
 	}
 
-	while ((c = getopt(argc, argv, "Facdfm:rstx")) != EOF) {
+	while ((c = getopt(argc, argv, "FRacdfm:nrstx")) != EOF) {
 		switch (c) {
 		case 'F':
 			flags |= IO_FOREIGN;
@@ -333,6 +294,9 @@ open_f(
 				return 0;
 			}
 			break;
+		case 'n':
+			flags |= IO_NONBLOCK;
+			break;
 		case 'r':
 			flags |= IO_READONLY;
 			break;
@@ -342,7 +306,8 @@ open_f(
 		case 't':
 			flags |= IO_TRUNC;
 			break;
-		case 'x':
+		case 'R':
+		case 'x':	/* backwards compatibility */
 			flags |= IO_REALTIME;
 			break;
 		default:
@@ -398,154 +363,153 @@ close_f(
 	return 0;
 }
 
-static int
-lsattr_f(
-	int		argc,
-	char		**argv)
-{
-	struct fsxattr	fsx;
-	int		c, aflag = 0, vflag = 0;
-
-	while ((c = getopt(argc, argv, "av")) != EOF) {
-		switch (c) {
-		case 'a':
-			aflag = 1;
-			vflag = 0;
-			break;
-		case 'v':
-			aflag = 0;
-			vflag = 1;
-			break;
-		default:
-			printf(_("invalid lsattr argument -- '%c'\n"), c);
-			return 0;
-		}
-	}
-
-	if ((xfsctl(file->name, file->fd, XFS_IOC_FSGETXATTR, &fsx)) < 0) {
-		perror("XFS_IOC_FSGETXATTR");
-	} else {
-		printxattr(fsx.fsx_xflags, vflag, !aflag, vflag, !aflag);
-		if (aflag) {
-			fputs("/", stdout);
-			printxattr(-1, 0, 1, 0, 1);
-		}
-	}
-	return 0;
-}
-
 static void
-lsattr_help(void)
+lsproj_help(void)
 {
 	printf(_(
 "\n"
-" displays the set of extended inode flags associated with the current file\n"
-"\n"
-" Each individual flag is displayed as a single character, in this order:\n"
-" r -- file data is stored in the realtime section\n"
-" p -- file has preallocated extents (cannot be changed using chattr)\n"
-" i -- immutable, file cannot be modified\n"
-" a -- append-only, file can only be appended to\n"
-" s -- all updates are synchronous\n"
-" A -- the access time is not updated for this inode\n"
-" d -- do not include this file in a dump of the filesystem\n"
+" displays the project identifier associated with the current path\n"
 "\n"
 " Options:\n"
-" -a -- show all flags which can be set alongside those which are set\n"
-" -v -- verbose mode; show long names of flags, not single characters\n"
+" -R -- recursively descend (useful when current path is a directory)\n"
+" -D -- recursively descend, but only list projects on directories\n"
 "\n"));
 }
 
 static int
-chattr_f(
+lsproj_callback(
+	const char		*path,
+	const struct stat	*stat,
+	int			status,
+	struct FTW		*data)
+{
+	prid_t			projid;
+	int			fd;
+
+	if (recurse_dir && !S_ISDIR(stat->st_mode))
+		return 0;
+
+	if ((fd = open(path, O_RDONLY)) == -1) {
+		fprintf(stderr, _("%s: cannot open %s: %s\n"),
+			progname, path, strerror(errno));
+	} else {
+		if (getprojid(path, fd, &projid) == 0)
+			printf("[%u] %s\n", projid, path);
+		close(fd);
+	}
+	return 0;
+}
+
+static int
+lsproj_f(
 	int		argc,
 	char		**argv)
 {
-	static struct {
-		int	flag;
-		char	optc;
-	} *p, xflags[] = {
-		{ XFS_XFLAG_REALTIME,	'r' },
-		{ XFS_XFLAG_IMMUTABLE,	'i' },
-		{ XFS_XFLAG_APPEND,	'a' },
-		{ XFS_XFLAG_SYNC,	's' },
-		{ XFS_XFLAG_NOATIME,	'A' },
-		{ XFS_XFLAG_NODUMP,	'd' },
-		{ 0, '\0' }
-	};
-	struct fsxattr	attr;
-	unsigned int	i = 0;
-	char		*c;
+	prid_t		projid;
+	int		c;
 
-	if (xfsctl(file->name, file->fd, XFS_IOC_FSGETXATTR, &attr) < 0) {
-		perror("XFS_IOC_FSGETXATTR");
-		return 0;
-	}
-	while (++i < argc) {
-		if (argv[i][0] == '+') {
-			for (c = &argv[i][1]; *c; c++) {
-				for (p = xflags; p->flag; p++) {
-					if (p->optc == *c) {
-						attr.fsx_xflags |= p->flag;
-						break;
-					}
-				}
-				if (!p->flag) {
-					fprintf(stderr, _("%s: unknown flag\n"),
-						progname);
-					return 0;
-				}
-			}
-		} else if (argv[i][0] == '-') {
-			for (c = &argv[i][1]; *c; c++) {
-				for (p = xflags; p->flag; p++) {
-					if (p->optc == *c) {
-						attr.fsx_xflags &= ~p->flag;
-						break;
-					}
-				}
-				if (!p->flag) {
-					fprintf(stderr, _("%s: unknown flag\n"),
-						progname);
-					return 0;
-				}
-			}
-		} else {
-			fprintf(stderr, _("%s: bad chattr command, not +/-X\n"),
-				progname);
-			return 0;
+	while ((c = getopt(argc, argv, "DR")) != EOF) {
+		switch (c) {
+		case 'D':
+			recurse_all = 0;
+			recurse_dir = 1;
+			break;
+		case 'R':
+			recurse_all = 1;
+			recurse_dir = 0;
+			break;
+		default:
+			return command_usage(&lsproj_cmd);
 		}
 	}
-	if (xfsctl(file->name, file->fd, XFS_IOC_FSSETXATTR, &attr) < 0)
-		perror("XFS_IOC_FSSETXATTR");
+
+	if (argc != optind)
+		return command_usage(&lsproj_cmd);
+
+	if (recurse_all || recurse_dir)
+		nftw(file->name, lsproj_callback,
+			100, FTW_PHYS | FTW_MOUNT | FTW_DEPTH);
+	else if (getprojid(file->name, file->fd, &projid) < 0)
+		perror("getprojid");
+	else
+		printf(_("projid = %u\n"), projid);
 	return 0;
 }
 
 static void
-chattr_help(void)
+chproj_help(void)
 {
 	printf(_(
 "\n"
-" modifies the set of extended inode flags associated with the current file\n"
+" modifies the project identifier associated with the current path\n"
 "\n"
-" Examples:\n"
-" 'chattr +a' - sets the append-only flag\n"
-" 'chattr -a' - clears the append-only flag\n"
-"\n"
-" +/-r -- set/clear the realtime flag\n"
-" +/-i -- set/clear the immutable flag\n"
-" +/-a -- set/clear the append-only flag\n"
-" +/-s -- set/clear the sync flag\n"
-" +/-A -- set/clear the no-atime flag\n"
-" +/-d -- set/clear the no-dump flag\n"
-" Note1: user must have certain capabilities to modify immutable/append-only.\n"
-" Note2: immutable/append-only files cannot be deleted; removing these files\n"
-"        requires the immutable/append-only flag to be cleared first.\n"
-" Note3: the realtime flag can only be set if the filesystem has a realtime\n"
-"        section, and the (regular) file must be empty when the flag is set.\n"
+" -R -- recursively descend (useful when current path is a directory)\n"
+" -D -- recursively descend, only modifying projects on directories\n"
 "\n"));
 }
 
+static int
+chproj_callback(
+	const char		*path,
+	const struct stat	*stat,
+	int			status,
+	struct FTW		*data)
+{
+	int			fd;
+
+	if (recurse_dir && !S_ISDIR(stat->st_mode))
+		return 0;
+
+	if ((fd = open(path, O_RDONLY)) == -1) {
+		fprintf(stderr, _("%s: cannot open %s: %s\n"),
+			progname, path, strerror(errno));
+	} else {
+		if (setprojid(path, fd, prid) < 0)
+			perror("setprojid");
+		close(fd);
+	}
+	return 0;
+}
+
+static int
+chproj_f(
+	int		argc,
+	char		**argv)
+{
+	int		c;
+
+	while ((c = getopt(argc, argv, "DR")) != EOF) {
+		switch (c) {
+		case 'D':
+			recurse_all = 0;
+			recurse_dir = 1;
+			break;
+		case 'R':
+			recurse_all = 1;
+			recurse_dir = 0;
+			break;
+		default:
+			return command_usage(&chproj_cmd);
+		}
+	}
+
+	if (argc != optind + 1)
+		return command_usage(&chproj_cmd);
+
+	prid = prid_from_string(argv[optind]);
+	if (prid == -1) {
+		printf(_("invalid project ID -- %s\n"), argv[optind]);
+		return 0;
+	}
+
+	if (recurse_all || recurse_dir)
+		nftw(file->name, chproj_callback,
+			100, FTW_PHYS | FTW_MOUNT | FTW_DEPTH);
+	else if (setprojid(file->name, file->fd, prid) < 0)
+		perror("setprojid");
+	return 0;
+}
+
 static int
 setfl_f(
 	int			argc,
@@ -592,7 +556,7 @@ extsize_f(
 {
 	struct fsxattr		fsx;
 	long			extsize;
-	int			blocksize, sectsize;
+	unsigned int		blocksize, sectsize;
 
 	init_cvtnum(&blocksize, &sectsize);
 	extsize = (long)cvtnum(blocksize, sectsize, argv[1]);
@@ -618,7 +582,8 @@ statfs_f(
 	int			argc,
 	char			**argv)
 {
-	struct xfs_fsop_geom_v1	fsgeo;
+	struct xfs_fsop_counts	fscounts;
+	struct xfs_fsop_geom	fsgeo;
 	struct statfs		st;
 
 	printf(_("fd.path = \"%s\"\n"), file->name);
@@ -629,7 +594,7 @@ statfs_f(
 		printf(_("statfs.f_blocks = %lld\n"), (long long) st.f_blocks);
 #if defined(__sgi__)
 		printf(_("statfs.f_frsize = %lld\n"), (long long) st.f_frsize);
-else
+#else
 		printf(_("statfs.f_bavail = %lld\n"), (long long) st.f_bavail);
 #endif
 		printf(_("statfs.f_files = %lld\n"), (long long) st.f_files);
@@ -653,6 +618,18 @@ else
 		printf(_("geom.sunit = %u\n"), fsgeo.sunit);
 		printf(_("geom.swidth = %u\n"), fsgeo.swidth);
 	}
+	if ((xfsctl(file->name, file->fd, XFS_IOC_FSCOUNTS, &fscounts)) < 0) {
+		perror("XFS_IOC_FSCOUNTS");
+	} else {
+		printf(_("counts.freedata = %llu\n"),
+			(unsigned long long) fscounts.freedata);
+		printf(_("counts.freertx = %llu\n"),
+			(unsigned long long) fscounts.freertx);
+		printf(_("counts.freeino = %llu\n"),
+			(unsigned long long) fscounts.freeino);
+		printf(_("counts.allocino = %llu\n"),
+			(unsigned long long) fscounts.allocino);
+	}
 	return 0;
 }
 
@@ -698,25 +675,25 @@ open_init(void)
 	statfs_cmd.oneline =
 		_("statistics on the filesystem of the currently open file");
 
-	chattr_cmd.name = _("chattr");
-	chattr_cmd.cfunc = chattr_f;
-	chattr_cmd.args = _("[+/-riasAd]");
-	chattr_cmd.argmin = 1;
-	chattr_cmd.argmax = 1;
-	chattr_cmd.flags = CMD_NOMAP_OK;
-	chattr_cmd.oneline =
-		_("change extended inode flags on the currently open file");
-	chattr_cmd.help = chattr_help;
+	chproj_cmd.name = _("chproj");
+	chproj_cmd.cfunc = chproj_f;
+	chproj_cmd.args = _("[-D | -R] projid");
+	chproj_cmd.argmin = 1;
+	chproj_cmd.argmax = -1;
+	chproj_cmd.flags = CMD_NOMAP_OK;
+	chproj_cmd.oneline =
+		_("change project identifier on the currently open file");
+	chproj_cmd.help = chproj_help;
 
-	lsattr_cmd.name = _("lsattr");
-	lsattr_cmd.cfunc = lsattr_f;
-	lsattr_cmd.args = _("[-a | -v]");
-	lsattr_cmd.argmin = 0;
-	lsattr_cmd.argmax = 2;
-	lsattr_cmd.flags = CMD_NOMAP_OK;
-	lsattr_cmd.oneline =
-		_("list extended inode flags set on the currently open file");
-	lsattr_cmd.help = lsattr_help;
+	lsproj_cmd.name = _("lsproj");
+	lsproj_cmd.cfunc = lsproj_f;
+	lsproj_cmd.args = _("[-D | -R]");
+	lsproj_cmd.argmin = 0;
+	lsproj_cmd.argmax = -1;
+	lsproj_cmd.flags = CMD_NOMAP_OK;
+	lsproj_cmd.oneline =
+		_("list project identifier set on the currently open file");
+	lsproj_cmd.help = lsproj_help;
 
 	extsize_cmd.name = _("extsize");
 	extsize_cmd.cfunc = extsize_f;
@@ -731,8 +708,8 @@ open_init(void)
 	add_command(&close_cmd);
 	add_command(&setfl_cmd);
 	add_command(&statfs_cmd);
-	add_command(&chattr_cmd);
-	add_command(&lsattr_cmd);
+	add_command(&chproj_cmd);
+	add_command(&lsproj_cmd);
 
 	if (expert)
 		add_command(&extsize_cmd);
