@@ -31,8 +31,8 @@
  */
 
 #include <xfs/libxfs.h>
-#include "command.h"
-#include "input.h"
+#include <xfs/command.h>
+#include <xfs/input.h>
 #include "init.h"
 #include "io.h"
 
@@ -47,7 +47,7 @@ offset_length(
 	char		*length,
 	xfs_flock64_t	*segment)
 {
-	int		blocksize, sectsize;
+	unsigned int	blocksize, sectsize;
 
 	init_cvtnum(&blocksize, &sectsize);
 	memset(segment, 0, sizeof(*segment));
