@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2002,2004 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -31,9 +31,6 @@
  */
 
 #include <libxfs.h>
-#include <xfs_acl.h>
-#include <xfs_cap.h>
-#include <xfs_mac.h>
 #include "globals.h"
 #include "err_protos.h"
 #include "attr_repair.h"
@@ -175,7 +172,7 @@ process_shortform_attr(
 
 	*repair = 0;
 
-	asf = (xfs_attr_shortform_t *) XFS_DFORK_APTR_ARCH(dip, ARCH_CONVERT);
+	asf = (xfs_attr_shortform_t *) XFS_DFORK_APTR(dip);
 
 	/* Assumption: hdr.totsize is less than a leaf block and was checked
 	 * by lclinode for valid sizes. Check the count though.
@@ -990,11 +987,11 @@ process_attributes(
 	xfs_attr_shortform_t *asf;
 
 	dinoc = &dip->di_core;
-	asf = (xfs_attr_shortform_t *) XFS_DFORK_APTR_ARCH(dip, ARCH_CONVERT);
+	asf = (xfs_attr_shortform_t *) XFS_DFORK_APTR(dip);
 
 	if (dinoc->di_aformat == XFS_DINODE_FMT_LOCAL) {
 		ASSERT(INT_GET(asf->hdr.totsize, ARCH_CONVERT) <=
-			XFS_DFORK_ASIZE_ARCH(dip, mp, ARCH_CONVERT));
+			XFS_DFORK_ASIZE(dip, mp));
 		err = process_shortform_attr(ino, dip, repair);
 	} else if (dinoc->di_aformat == XFS_DINODE_FMT_EXTENTS ||
 		   dinoc->di_aformat == XFS_DINODE_FMT_BTREE)  {
